SVDLIBC: Sparse Text Matrix File Format

## SVD_F_ST

### Sparse Text Matrix File Format

### Format:

    numRows numCols totalNonZeroValues
    for each column:
      numNonZeroValues
      for each non-zero value in the column:
        rowIndex value

Rows are indexed starting with 0. Newlines and spaces are equivalent.

### Example:

Dense Text Format:

    4 3
    2.3  0  4.2
    0   1.3 2.2
    3.8  0  0.5
    0    0   0

Sparse Text Format:

    4 3 6
    2
    0 2.3
    2 3.8
    1
    1 1.3
    3
    0 4.2
    1 2.2
    2 0.5